==> tabular-data-gwt-service-2.5.0-20141211.113759-174-servicearchive.tar.gz: org/gcube/portlets/user/td/gwtservice/shared/task/TaskS.java <==
package org.gcube.portlets.user.td.gwtservice.shared.task;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;

/**
 * 
 * @author "Giancarlo Panichi"
 * 
 */
public class TaskS implements Serializable {

	private static final long serialVersionUID = 8228657333318157153L;

	protected String id;
	protected float progress;
	protected State state;
	protected Throwable errorCause;
	protected String submitter;
	protected Date startTime;
	protected Date endTime;
	protected ArrayList<JobS> jobs;

	public TaskS() {

	}
	
	/**
	 * 
	 * @param id
	 * @param progress
	 * @param state
	 * @param errorCause
	 * @param submitter
	 * @param startTime
	 * @param endTime
	 * @param jobs
	 */
	public TaskS(String id, float progress, State state, Throwable errorCause, String submitter,
			Date startTime, Date endTime, ArrayList<JobS> jobs) {
		this.id = id;
		this.progress = progress;
		this.state = state;
		this.errorCause=errorCause;
		this.submitter = submitter;
		this.startTime = startTime;
		this.endTime = endTime;
		this.jobs = jobs;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public float getProgress() {
		return progress;
	}

	public void setProgress(float progress) {
		this.progress = progress;
	}

	public State getState() {
		return state;
	}

	public void setState(State state) {
		this.state = state;
	}

	public Throwable getErrorCause() {
		return errorCause;
	}

	public void setErrorCause(Throwable errorCause) {
		this.errorCause = errorCause;
	}

	public String getSubmitter() {
		return submitter;
	}

	public void setSubmitter(String submitter) {
		this.submitter = submitter;
	}

	public Date getStartTime() {
		return startTime;
	}

	public void setStartTime(Date startTime) {
		this.startTime = startTime;
	}

	public Date getEndTime() {
		return endTime;
	}

	public void setEndTime(Date endTime) {
		this.endTime = endTime;
	}

	public ArrayList<JobS> getJobs() {
		return jobs;
	}

	public void setJobs(ArrayList<JobS> jobs) {
		this.jobs = jobs;
	}

	@Override
	public String toString() {
		return "TaskS [id=" + id + ", progress=" + progress + ", state="
				+ state + ", errorCause=" + errorCause + ", submitter="
				+ submitter + ", startTime=" + startTime + ", endTime="
				+ endTime + ", jobs=" + jobs + "]";
	}

	

}

==> tabular-data-gwt-service-2.9.0-20151109.172353-46-servicearchive.tar.gz: org/gcube/portlets/user/td/gwtservice/shared/task/TaskS.java <==
package org.gcube.portlets.user.td.gwtservice.shared.task;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;

import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;

/**
 * 
 * @author "Giancarlo Panichi"
 * 
 */
public class TaskS implements Serializable {

	private static final long serialVersionUID = 8228657333318157153L;

	private String id;
	private float progress;
	private State state;
	private Throwable errorCause;
	private String submitter;
	private Date startTime;
	private Date endTime;
	private ArrayList<JobS> jobs;
	private ArrayList<TRId> collateralTRIds;
	private String tabularResourceId;

	public TaskS() {

	}

	/**
	 * 
	 * @param id
	 * @param progress
	 * @param state
	 * @param errorCause
	 * @param submitter
	 * @param startTime
	 * @param endTime
	 * @param jobs
	 * @param collateralTRIds
	 * @param tabularResourceId TODO
	 *            
	 */
	public TaskS(String id, float progress, State state, Throwable errorCause,
			String submitter, Date startTime, Date endTime,
			ArrayList<JobS> jobs, ArrayList<TRId> collateralTRIds, String tabularResourceId) {
		this.id = id;
		this.progress = progress;
		this.state = state;
		this.errorCause = errorCause;
		this.submitter = submitter;
		this.startTime = startTime;
		this.endTime = endTime;
		this.jobs = jobs;
		this.collateralTRIds = collateralTRIds;
		this.tabularResourceId=tabularResourceId;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public float getProgress() {
		return progress;
	}

	public void setProgress(float progress) {
		this.progress = progress;
	}

	public State getState() {
		return state;
	}

	public void setState(State state) {
		this.state = state;
	}

	public Throwable getErrorCause() {
		return errorCause;
	}

	public void setErrorCause(Throwable errorCause) {
		this.errorCause = errorCause;
	}

	public String getSubmitter() {
		return submitter;
	}

	public void setSubmitter(String submitter) {
		this.submitter = submitter;
	}

	public Date getStartTime() {
		return startTime;
	}

	public void setStartTime(Date startTime) {
		this.startTime = startTime;
	}

	public Date getEndTime() {
		return endTime;
	}

	public void setEndTime(Date endTime) {
		this.endTime = endTime;
	}

	public ArrayList<JobS> getJobs() {
		return jobs;
	}

	public void setJobs(ArrayList<JobS> jobs) {
		this.jobs = jobs;
	}

	public ArrayList<TRId> getCollateralTRIds() {
		return collateralTRIds;
	}

	public void setCollateralTRIds(ArrayList<TRId> collateralTRIds) {
		this.collateralTRIds = collateralTRIds;
	}
	
	public String getTabularResourceId() {
		return tabularResourceId;
	}

	public void setTabularResourceId(String tabularResourceId) {
		this.tabularResourceId = tabularResourceId;
	}

	@Override
	public String toString() {
		return "TaskS [id=" + id + ", progress=" + progress + ", state="
				+ state + ", errorCause=" + errorCause + ", submitter="
				+ submitter + ", startTime=" + startTime + ", endTime="
				+ endTime + ", jobs=" + jobs + ", collateralTRIds="
				+ collateralTRIds + ", tabularResourceId=" + tabularResourceId
				+ "]";
	}

	
}
